==> members-facade-2.0.1-vg-20231023.122701-11-sources.jar: com/bizvane/members/facade/enums/OpenCardChannelEnum.java <==
package com.bizvane.members.facade.enums;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/13.
 */
public enum OpenCardChannelEnum {
    /**
     * 会员开卡绑卡渠道 线下渠道
     */
    OFFLINE_CHANNEL(1L,"100001", "线下渠道"),
    /**
     * 会员开卡绑卡渠道 微信渠道
     */
    WECHAT_CHANNEL(2L, "100002","微信小程序渠道"),
    /**
     * 会员开卡绑卡渠道 支付宝渠道
     */
    ALIPAY_CHANNEL(3L, "100003","支付宝小程序渠道"),
    /**
     * 会员开卡绑卡渠道 天猫渠道
     */
    TAOBAO_CHANNEL(4L, "100004","天猫渠道"),
    /**
     * 会员开卡绑卡渠道 电子会员卡渠道
     */
    ELECTCARD_CHANNEL(5L, "100005","微信电子会员卡渠道"),
    /**
     * 会员开卡绑卡渠道 微商城
     */
    MALL(6L, "100006","锦集商城"),
    /**
     * 会员开卡绑卡渠道 手动导入渠道
     */
    IMPORT_CHANNEL(7L,"100007", "手动导入渠道"),
    /**
     * 会员开卡绑卡渠道 微盟商城
     */
    MALL_WEIMOB_CHANNEL(8L, "100008","微盟商城"),
    /**
     * 会员开卡绑卡渠道 EHR
     */
    EHR(9L,"100009","EHR"),
    /**
     * 会员开卡绑卡渠道 其它渠道
     */
    OTHER_CHANNEL(10L,"100010","其它渠道"),
    /**
     * 会员开卡绑卡渠道 有赞渠道
     */
    YOUZAN_CHANNEL(11L,"100011","有赞渠道"),
    /**
     * 会员开卡绑卡渠道 支付宝渠道
     */
    ALIPAY_CARD_CHANNEL(12L, "100012","支付宝电子会员卡渠道"),
    /**
     * 甲方平台
     */
    PARTY_PLATFORM(13L, "100013", "甲方平台");
    private Long code;

    private String channelCode;

    private String msg;

    OpenCardChannelEnum(Long code, String channelCode, String msg) {
        this.code = code;
        this.channelCode = channelCode;
        this.msg = msg;
    }

    public Long getCode() {
        return code;
    }

    public void setCode(Long code) {
        this.code = code;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public String getChannelCode() {
        return channelCode;
    }

    /**
     * 根据枚举code获得枚举msg
     *
     * @param code
     * @return
     */
    public static String getOpenCardChanneMessage(Long code) {
        for (OpenCardChannelEnum type : OpenCardChannelEnum.values()) {
            if (type.getCode().equals(code)) {
                return type.getMsg();
            }
        }
        return "";
    }
}

==> members-facade-2.0.2-vg-20251111.101130-21-sources.jar: com/bizvane/members/facade/enums/OpenCardChannelEnum.java <==
package com.bizvane.members.facade.enums;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/13.
 */
public enum OpenCardChannelEnum {
    /**
     * 会员开卡绑卡渠道 线下渠道
     */
    OFFLINE_CHANNEL(1L,"100001", "线下渠道"),
    /**
     * 会员开卡绑卡渠道 微信渠道
     */
    WECHAT_CHANNEL(2L, "100002","微信小程序渠道"),
    /**
     * 会员开卡绑卡渠道 支付宝渠道
     */
    ALIPAY_CHANNEL(3L, "100003","支付宝小程序渠道"),
    /**
     * 会员开卡绑卡渠道 天猫渠道
     */
    TAOBAO_CHANNEL(4L, "100004","天猫渠道"),
    /**
     * 会员开卡绑卡渠道 电子会员卡渠道
     */
    ELECTCARD_CHANNEL(5L, "100005","微信电子会员卡渠道"),
    /**
     * 会员开卡绑卡渠道 微商城
     */
    MALL(6L, "100006","锦集商城"),
    /**
     * 会员开卡绑卡渠道 手动导入渠道
     */
    IMPORT_CHANNEL(7L,"100007", "手动导入渠道"),
    /**
     * 会员开卡绑卡渠道 微盟商城
     */
    MALL_WEIMOB_CHANNEL(8L, "100008","微盟商城"),
    /**
     * 会员开卡绑卡渠道 EHR
     */
    EHR(9L,"100009","EHR"),
    /**
     * 会员开卡绑卡渠道 其它渠道
     */
    OTHER_CHANNEL(10L,"100010","其它渠道"),
    /**
     * 会员开卡绑卡渠道 有赞渠道
     */
    YOUZAN_CHANNEL(11L,"100011","有赞渠道"),
    /**
     * 会员开卡绑卡渠道 支付宝渠道
     */
    ALIPAY_CARD_CHANNEL(12L, "100012","支付宝电子会员卡渠道"),
    /**
     * 甲方平台
     */
    PARTY_PLATFORM(13L, "100013", "甲方平台-八百伴"),
    /**
     * 甲方平台
     */
    PARTY_PLATFORM_EIGHT_STORE(14L, "100014", "甲方平台-八号仓");
    private Long code;

    private String channelCode;

    private String msg;

    OpenCardChannelEnum(Long code, String channelCode, String msg) {
        this.code = code;
        this.channelCode = channelCode;
        this.msg = msg;
    }

    public Long getCode() {
        return code;
    }

    public void setCode(Long code) {
        this.code = code;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public String getChannelCode() {
        return channelCode;
    }

    /**
     * 根据枚举code获得枚举msg
     *
     * @param code
     * @return
     */
    public static String getOpenCardChanneMessage(Long code) {
        for (OpenCardChannelEnum type : OpenCardChannelEnum.values()) {
            if (type.getCode().equals(code)) {
                return type.getMsg();
            }
        }
        return "";
    }
}
